powered by
This function renames columns in case the input data.frame includes any colnames required by internal functions (e.g., "y").
"y"
col_rename(df, old_name)
Input data.frame.
Name of column to be renamed.